This is the python ``mmgroup`` project.

It gives the user the capability to compute in the Monster group.
In mathematics, the Monster group is the largest finite sporadic
simple group.

Project Documentation see

https://mmgroup.readthedocs.io/en/latest/


License
-------

Copyright Martin Seysen, 2020.

Distributed under the terms of the `MIT`_ license, mmgroup is free and 
open source software.

.. _`MIT`: https://github.com/Martin-Seysen/test_repository/blob/master/LICENSE

